@@ -1,4 +1,5 @@
 #!/usr/bin/env python3
+import traceback
 from flask import Flask, render_template, request, send_from_directory, url_for, redirect
 from flask_basicauth import BasicAuth
 from flask_apscheduler import APScheduler
@@ -112,6 +113,7 @@ def updateImeshMap(interface, packet):
                            "hopLimit":packet.get('hopLimit'), "rxTime":packet.get('rxTime')}))
     try:
         for node, nodeValue in receivedNodes.items():
+            
             try:
                 mapNodes.append([nodeValue['user']['longName'], nodeValue['position']['latitude'],
                                  nodeValue['position']['longitude'], getMapNodeInfo(nodeValue)[0], getMapNodeInfo(nodeValue)[1], getHourDiff(nodeValue['position']['time'])])
@@ -121,15 +123,15 @@ def updateImeshMap(interface, packet):
                         print("aggiornato")
                         client.publish("receivedNodes/"+node, json.dumps(nodeValue))
                 else:
-                    print(" nuovo nodo ricevuto: "+node +" - "+ nodeValue['user']['longName'])
+                    print("New node received: "+node +" - "+ nodeValue['user']['longName']+" @ "+str(nodeValue['position'].get('time')))
                     if(config['MQTT']['enabled']=="True"):
                         client.publish("receivedNodes/"+node, json.dumps(nodeValue))
-                    print(str(nodeValue['position'].get('time')))
             except Exception as e:
-                print(e)
+                traceback.print_exc()
+                print(nodeValue)
         oldReceivedNodes = copy.deepcopy(receivedNodes)
     except Exception as e:
-        print(e)
+        traceback.print_exc()
 
 def getHourDiff(TS):
     return int((int(time.time())-int(TS))/3600)
@@ -190,8 +192,10 @@ def send_img(path):
 @app.route('/')
 def indexPage():
     getNodes()
+    radioPrefs = interface.localNode.radioConfig.preferences
     return render_template('index.html', Title="iMesh Node Landing Page", 
-                                         nodeInfo=myNodeInfo, info=interface.myInfo, appData=appData)
+                                         nodeInfo=myNodeInfo, info=interface.myInfo,
+                                         appData=appData, prefs=radioPrefs)
 
 @app.route('/lh')
 def lhPage():
@@ -209,8 +213,10 @@ def mapPage():
 @basic_auth.required
 def configPage():
     getNodes()
+    radioPrefs = interface.localNode.radioConfig.preferences
     return render_template('config.html', Title="Nodes Map", 
-                                          nodeInfo=myNodeInfo, appData=appData, nodes=receivedNodes.items())
+                                          nodeInfo=myNodeInfo, appData=appData,
+                                          nodes=receivedNodes.items(), prefs=radioPrefs)
 
 @app.route('/getNodes')
 def printNodes():
@@ -232,22 +238,22 @@ def sendMessage():
 @basic_auth.required
 def setNode():
     if request.method == 'POST':
+        radioPrefs = interface.localNode.radioConfig.preferences
         interface.waitForConfig()
-        interface.setOwner(request.form['flongName'],  request.form['fshortName'])
-        interface.waitForConfig()
-        prefs = interface.radioConfig.preferences
+        interface.localNode.setOwner(request.form['flongName'],  request.form['fshortName'])
+        interface.localNode.waitForConfig()
+        setattr(radioPrefs, "region", int(request.form['fRegion']))
         alt = int(request.form['faltitude'])
         lat = float(request.form['flatitude'])
         lon = float(request.form['flongitude'])
         ts = int(time.time())
         if not interface.myInfo.has_gps and not (positionBeacon):
-            prefs.fixed_position = True
+            setattr(radioPrefs, "fixed_position", True)
             interface.sendPosition(lat, lon, alt, ts)
-            interface.waitForConfig()
-            interface.writeConfig()
         else:
             print("Cannot set node parameters beacuse has gps: %s or has fixed position config in config file: %s" % 
                    (interface.myInfo.has_gps, (positionBeacon),))
+        interface.localNode.writeConfig()
     return redirect(url_for('configPage'))
 
 @app.route('/setGpio', methods=['POST'])
@@ -321,8 +327,11 @@ def main():
     if(config['MQTT']['enabled']=="True"):
         client.connect(config['MQTT']['host'], int(config['MQTT']['port']), int(config['MQTT']['keepalive']))
         client.loop_start()
-    getNodeInfo()
-    updateImeshMap(interface, None)
+    try:
+        getNodeInfo()
+        updateImeshMap(interface, None)
+    except Exception as e:
+        traceback.print_exc()
     pub.subscribe(updateImeshMap, "meshtastic.receive")
     pub.subscribe(onGPIOreceive, "meshtastic.receive.data.REMOTE_HARDWARE_APP")
     atexit.register(lambda: interface.close())
